summaryrefslogtreecommitdiffstats
path: root/src/bitfield/8byte.h
diff options
context:
space:
mode:
authorChristopher Peplin <chris.peplin@rhubarbtech.com>2013-12-29 11:55:35 -0500
committerChristopher Peplin <chris.peplin@rhubarbtech.com>2013-12-29 12:00:52 -0500
commitc2c7ef1dfe4cae6b5831ffab0ce5780b27e0c25e (patch)
treed490768ad2effe746406c60419aae905cfeead83 /src/bitfield/8byte.h
parent6ce03a4f1b229e605da08b073fad6f7c0fe8bf10 (diff)
Standardize on snake_case naming as this is a C library.
Diffstat (limited to 'src/bitfield/8byte.h')
-rw-r--r--src/bitfield/8byte.h29
1 files changed, 15 insertions, 14 deletions
diff --git a/src/bitfield/8byte.h b/src/bitfield/8byte.h
index 13b6aff3..9cbf61a9 100644
--- a/src/bitfield/8byte.h
+++ b/src/bitfield/8byte.h
@@ -14,17 +14,17 @@ extern "C" {
// inefficient on 32-bit platforms. how much work is it to switch vi-firmware
// to using uint8_t*?
-/* Public: Reads a subset of bits from a byte array.
+/* Public: Reads a subset of bits into a uint64_t.
*
* data - the bytes in question.
* startPos - the starting index of the bit field (beginning from 0).
* numBits - the width of the bit field to extract.
* bigEndian - if the data passed in is little endian, set this to false and it
* will be flipped before grabbing the bit field.
*
* Bit fields are positioned according to big-endian bit layout, but inside the
* bit field, values are represented as little-endian. Therefore, to get the bit
* field, we swap the overall byte order if bigEndian == false and
* use the value we find in the field (assuming the embedded platform is little
* endian).
*
@@ -42,30 +42,31 @@ extern "C" {
*
* Examples
*
- * uint64_t value = getBitField(data, 2, 4);
+ * uint64_t value = get_bit_field(data, 2, 4);
*
* Returns the value of the requested bit field.
*/
-uint64_t getBitField(uint64_t data, const uint16_t startPos,
- const uint16_t numBits, bool bigEndian);
+uint64_t get_bit_field(uint64_t source, const uint16_t offset,
+ const uint16_t bit_count, bool big_endian);
/* Public: Set the bit field in the given data array to the new value.
*
- * data - a byte array with size at least startPos + numBits.
+ * destination - a byte array with size at least offset + bit_count.
* value - the value to set in the bit field.
- * startPos - the starting index of the bit field (beginning from 0).
+ * offset - the starting index of the bit field (beginning from 0).
+ * bit_count - the number of bits to set in the data.
*/
-void setBitField(uint64_t* data, uint64_t value, const uint16_t startPos,
- const uint16_t numBits);
+void set_bit_field(uint64_t* destination, uint64_t value, const uint16_t offset,
+ const uint16_t bit_count);
/* Public: Retreive the nth byte out of 8 bytes in a uint64_t.
*
* source - the source data to retreive the byte from.
* byteNum - the index of the byte, starting at 0 and assuming big-endian order.
*
* Returns the requested byte from the source bytes.
*/
-uint8_t nthByte(const uint64_t source, const uint16_t byteNum);
+uint8_t nth_byte(const uint64_t source, const uint16_t byte_index);
#ifdef __cplusplus
}
@@ -14,17 +14,17 @@ extern "C" {
*
- * data - the bytes in question.
- * startPos - the starting index of the bit field (beginning from 0).
+ * source - the bytes in question.
+ * offset - the starting index of the bit field (beginning from 0).
* numBits - the width of the bit field to extract.
@@ -14,17 +14,17 @@ extern "C" {
* numBits - the width of the bit field to extract.
- * bigEndian - if the data passed in is little endian, set this to false and it
+ * big_endian - if the data passed in is little endian, set this to false and it
* will be flipped before grabbing the bit field.
*
@@ -14,17 +14,17 @@ extern "C" {
* Bit fields are positioned according to big-endian bit layout, but inside the
* bit field, values are represented as little-endian. Therefore, to get the bit
- * field, we swap the overall byte order if bigEndian == false and
+ * field, we swap the overall byte order if big_endian == false and
* use the value we find in the field (assuming the embedded platform is little
* endian).
@@ -42,30 +42,31 @@ extern "C" {
*
* source - the source data to retreive the byte from.
- * byteNum - the index of the byte, starting at 0 and assuming big-endian order.
+ * byte_index - the index of the byte, starting at 0 and assuming big-endian order.
*
* Returns the requested byte from the source bytes.